Struct GaiFuture

struct GaiFuture { ... }

A future to resolve a name returned by GaiResolver.

Implementations

impl Debug for GaiFuture

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Drop for GaiFuture

fn drop(self: &mut Self)

impl Freeze for GaiFuture

impl Future for GaiFuture

fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<<Self as >::Output>

impl RefUnwindSafe for GaiFuture

impl Send for GaiFuture

impl Sync for GaiFuture

impl Unpin for GaiFuture

impl UnsafeUnpin for GaiFuture

impl UnwindSafe for GaiFuture

impl<F> IntoFuture for GaiFuture

fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture

impl<F, T, E> TryFuture for GaiFuture

fn try_poll(self: Pin<&mut F>, cx: &mut Context<'_>) -> Poll<<F as Future>::Output>

impl<Fut> TryFutureExt for GaiFuture

impl<T> Any for GaiFuture

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for GaiFuture

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for GaiFuture

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for GaiFuture

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> FutureExt for GaiFuture

impl<T> Instrument for GaiFuture

impl<T> WithSubscriber for GaiFuture

impl<T, U> Into for GaiFuture

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for GaiFuture

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for GaiFuture

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>