Struct SocksV4
struct SocksV4<C> { ... }
Tunnel Proxy via SOCKSv4
This is a connector that can be used by the legacy::Client. It wraps
another connector, and after getting an underlying connection, it established
a TCP tunnel over it using SOCKSv4.
Implementations
impl<C> SocksV4<C>
fn new(proxy_dst: Uri, connector: C) -> SelfCreate a new SOCKSv4 handshake service
Wraps an underlying connector and stores the address of a tunneling proxying server.
A
SocksV4can then be called with any destination. Thedstpassed tocallwill not be used to create the underlying connection, but will be used in a SOCKS handshake with the proxy destination.fn local_dns(self: Self, local_dns: bool) -> SelfResolve domain names locally on the client, rather than on the proxy server.
Disabled by default as local resolution of domain names can be detected as a DNS leak.
impl<C> Freeze for SocksV4<C>
impl<C> RefUnwindSafe for SocksV4<C>
impl<C> Send for SocksV4<C>
impl<C> Service for SocksV4<C>
fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>fn call(self: &mut Self, dst: Uri) -> <Self as >::Future
impl<C> Sync for SocksV4<C>
impl<C> Unpin for SocksV4<C>
impl<C> UnsafeUnpin for SocksV4<C>
impl<C> UnwindSafe for SocksV4<C>
impl<C: $crate::clone::Clone> Clone for SocksV4<C>
fn clone(self: &Self) -> SocksV4<C>
impl<C: $crate::fmt::Debug> Debug for SocksV4<C>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for SocksV4<C>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SocksV4<C>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SocksV4<C>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for SocksV4<C>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for SocksV4<C>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Instrument for SocksV4<C>
impl<T> ToOwned for SocksV4<C>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> WithSubscriber for SocksV4<C>
impl<T, U> Into for SocksV4<C>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SocksV4<C>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SocksV4<C>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>