Struct HttpInfo

struct HttpInfo { ... }

Extra information about the transport when an HttpConnector is used.

Example

# fn doc(res: http::Response<()>) {
use hyper_util::client::legacy::connect::HttpInfo;

// res = http::Response
res
    .extensions()
    .get::<HttpInfo>()
    .map(|info| {
        println!("remote addr = {}", info.remote_addr());
    });
# }

Note

If a different connector is used besides HttpConnector, this value will not exist in the extensions. Consult that specific connector to see what "extra" information it might provide to responses.

Implementations

impl HttpInfo

fn remote_addr(self: &Self) -> SocketAddr

Get the remote address of the transport used.

fn local_addr(self: &Self) -> SocketAddr

Get the local address of the transport used.

impl Clone for HttpInfo

fn clone(self: &Self) -> HttpInfo

impl Debug for HttpInfo

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for HttpInfo

impl RefUnwindSafe for HttpInfo

impl Send for HttpInfo

impl Sync for HttpInfo

impl Unpin for HttpInfo

impl UnsafeUnpin for HttpInfo

impl UnwindSafe for HttpInfo

impl<T> Any for HttpInfo

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for HttpInfo

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for HttpInfo

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for HttpInfo

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for HttpInfo

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for HttpInfo

impl<T> ToOwned for HttpInfo

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for HttpInfo

impl<T, U> Into for HttpInfo

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for HttpInfo

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for HttpInfo

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>