pub struct Cached<S> { /* private fields */ }Available on
docsrs and crate feature client-pool and crate feature client only.Expand description
A cached service returned from a Cache.
Implements Service by delegating to the inner service. Once dropped,
tries to reinsert into the Cache.
Unnameable
This type is normally unnameable, forbidding naming of the type within code. The type is exposed in the documentation to show which methods can be publicly called.
Implementations