WithSpanExecutor

Struct WithSpanExecutor 

pub struct WithSpanExecutor<E> { /* private fields */ }
Available on crate feature tracing only.
An executor that propagates a provided tracing span to its futures.

The span provided to this executor is entered each time the future is polled or dropped. Execution is delegated to the wrapped executor, without requiring a particular runtime.

Requires the tracing feature.

Example

use hyper_util::rt::{TokioExecutor, WithSpanExecutor};

let span = tracing::info_span!("example");
let executor = WithSpanExecutor::new(TokioExecutor::new(), span);

Implementations

Source

impl<E> WithSpanExecutor<E>

pub fn new(inner: E, span: Span) -> Self

Wrap an executor to propagate the provided tracing span to its futures.

pub fn current(inner: E) -> Self

Wrap an executor to propagate the current tracing span to its futures.

This will instrument futures with the span that is active at the call-site of this function. Use CurrentSpanExecutor<E> if you would prefer to propagate the current span when Executor::execute() is called, rather than span that is active when initializating the executor.