Struct Http2Builder

struct Http2Builder<'a, E> { ... }

Http2 part of builder.

Implementations

impl<E> Http2Builder<'_, E>

fn http1(self: &mut Self) -> Http1Builder<'_, E>

Http1 configuration.

fn max_pending_accept_reset_streams<impl Into<Option<usize>>: Into<Option<usize>>>(self: &mut Self, max: impl Into<Option<usize>>) -> &mut Self

Configures the maximum number of pending reset streams allowed before a GOAWAY will be sent.

This will default to the default value set by the h2 crate. As of v0.4.0, it is 20.

See https://github.com/hyperium/hyper/issues/2877 for more information.

fn max_local_error_reset_streams<impl Into<Option<usize>>: Into<Option<usize>>>(self: &mut Self, max: impl Into<Option<usize>>) -> &mut Self

Configures the maximum number of local reset streams allowed before a GOAWAY will be sent.

If not set, hyper will use a default, currently of 1024.

If None is supplied, hyper will not apply any limit. This is not advised, as it can potentially expose servers to DOS vulnerabilities.

See https://rustsec.org/advisories/RUSTSEC-2024-0003.html for more information.

fn initial_stream_window_size<impl Into<Option<u32>>: Into<Option<u32>>>(self: &mut Self, sz: impl Into<Option<u32>>) -> &mut Self

Sets the SETTINGS_INITIAL_WINDOW_SIZE option for HTTP2 stream-level flow control.

Passing None will do nothing.

If not set, hyper will use a default.

fn initial_connection_window_size<impl Into<Option<u32>>: Into<Option<u32>>>(self: &mut Self, sz: impl Into<Option<u32>>) -> &mut Self

Sets the max connection-level flow control for HTTP2.

Passing None will do nothing.

If not set, hyper will use a default.

fn adaptive_window(self: &mut Self, enabled: bool) -> &mut Self

Sets whether to use an adaptive flow control.

Enabling this will override the limits set in http2_initial_stream_window_size and http2_initial_connection_window_size.

fn max_frame_size<impl Into<Option<u32>>: Into<Option<u32>>>(self: &mut Self, sz: impl Into<Option<u32>>) -> &mut Self

Sets the maximum frame size to use for HTTP2.

Passing None will do nothing.

If not set, hyper will use a default.

fn max_concurrent_streams<impl Into<Option<u32>>: Into<Option<u32>>>(self: &mut Self, max: impl Into<Option<u32>>) -> &mut Self

Sets the SETTINGS_MAX_CONCURRENT_STREAMS option for HTTP2 connections.

Default is 200. Passing None will remove any limit.

fn keep_alive_interval<impl Into<Option<Duration>>: Into<Option<Duration>>>(self: &mut Self, interval: impl Into<Option<Duration>>) -> &mut Self

Sets an interval for HTTP2 Ping frames should be sent to keep a connection alive.

Pass None to disable HTTP2 keep-alive.

Default is currently disabled.

Cargo Feature

fn keep_alive_timeout(self: &mut Self, timeout: Duration) -> &mut Self

Sets a timeout for receiving an acknowledgement of the keep-alive ping.

If the ping is not acknowledged within the timeout, the connection will be closed. Does nothing if http2_keep_alive_interval is disabled.

Default is 20 seconds.

Cargo Feature

fn max_send_buf_size(self: &mut Self, max: usize) -> &mut Self

Set the maximum write buffer size for each HTTP/2 stream.

Default is currently ~400KB, but may change.

Panics

The value must be no larger than u32::MAX.

fn enable_connect_protocol(self: &mut Self) -> &mut Self

Enables the extended CONNECT protocol.

fn max_header_list_size(self: &mut Self, max: u32) -> &mut Self

Sets the max size of received header frames.

Default is currently ~16MB, but may change.

fn timer<M>(self: &mut Self, timer: M) -> &mut Self
where
    M: Timer + Send + Sync + 'static

Set the timer used in background tasks.

fn auto_date_header(self: &mut Self, enabled: bool) -> &mut Self

Set whether the date header should be included in HTTP responses.

Note that including the date header is recommended by RFC 7231.

Default is true.

async fn serve_connection<I, S, B>(self: &Self, io: I, service: S) -> Result<(), Box<dyn Error + Send + Sync>>
where
    S: Service<Request<Incoming>, Response = Response<B>>,
    <S as >::Future: 'static,
    <S as >::Error: Into<Box<dyn StdError + Send + Sync>>,
    B: Body + 'static,
    <B as >::Error: Into<Box<dyn StdError + Send + Sync>>,
    I: Read + Write + Unpin + 'static,
    E: HttpServerConnExec<<S as >::Future, B>

Bind a connection together with a Service.

fn serve_connection_with_upgrades<I, S, B>(self: &Self, io: I, service: S) -> UpgradeableConnection<'_, I, S, E>
where
    S: Service<Request<Incoming>, Response = Response<B>>,
    <S as >::Future: 'static,
    <S as >::Error: Into<Box<dyn StdError + Send + Sync>>,
    B: Body + 'static,
    <B as >::Error: Into<Box<dyn StdError + Send + Sync>>,
    I: Read + Write + Unpin + Send + 'static,
    E: HttpServerConnExec<<S as >::Future, B>

Bind a connection together with a Service, with the ability to handle HTTP upgrades. This requires that the IO object implements Send.

impl<'a, E> Freeze for Http2Builder<'a, E>

impl<'a, E> RefUnwindSafe for Http2Builder<'a, E>

impl<'a, E> Send for Http2Builder<'a, E>

impl<'a, E> Sync for Http2Builder<'a, E>

impl<'a, E> Unpin for Http2Builder<'a, E>

impl<'a, E> UnsafeUnpin for Http2Builder<'a, E>

impl<'a, E> UnwindSafe for Http2Builder<'a, E>

impl<T> Any for Http2Builder<'a, E>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Http2Builder<'a, E>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Http2Builder<'a, E>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Http2Builder<'a, E>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for Http2Builder<'a, E>

impl<T> WithSubscriber for Http2Builder<'a, E>

impl<T, U> Into for Http2Builder<'a, E>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Http2Builder<'a, E>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Http2Builder<'a, E>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>