Struct TowerToHyperService

struct TowerToHyperService<S> { ... }

A tower Service converted into a hyper Service.

This wraps an inner tower service S in a hyper::service::Service implementation. See the module-level documentation of [service][crate::service] for more information about using tower services and middleware with hyper.

Implementations

impl<S> TowerToHyperService<S>

fn new(tower_service: S) -> Self

Create a new TowerToHyperService from a tower service.

impl<S> Freeze for TowerToHyperService<S>

impl<S> RefUnwindSafe for TowerToHyperService<S>

impl<S> Send for TowerToHyperService<S>

impl<S> Sync for TowerToHyperService<S>

impl<S> Unpin for TowerToHyperService<S>

impl<S> UnsafeUnpin for TowerToHyperService<S>

impl<S> UnwindSafe for TowerToHyperService<S>

impl<S, R> Service for TowerToHyperService<S>

fn call(self: &Self, req: R) -> <Self as >::Future

impl<S: $crate::clone::Clone> Clone for TowerToHyperService<S>

fn clone(self: &Self) -> TowerToHyperService<S>

impl<S: $crate::fmt::Debug> Debug for TowerToHyperService<S>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<S: $crate::marker::Copy> Copy for TowerToHyperService<S>

impl<T> Any for TowerToHyperService<S>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TowerToHyperService<S>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TowerToHyperService<S>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TowerToHyperService<S>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for TowerToHyperService<S>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for TowerToHyperService<S>

impl<T> ToOwned for TowerToHyperService<S>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for TowerToHyperService<S>

impl<T, B1, B2> HttpService for TowerToHyperService<S>

fn call(self: &mut Self, req: Request<B1>) -> <T as HttpService<B1>>::Future

impl<T, U> Into for TowerToHyperService<S>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TowerToHyperService<S>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TowerToHyperService<S>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>