Utilities for working with hyper.
This crate is less-stable than hyper. However,
does respect Rust’s semantic version regarding breaking changes.
Feature flags
hyper-util relies on feature flags to allow dependents to opt into
building particular components. None of these feature flags are enabled by
default. You may use the full feature flag to enable all of the standard
features.
Note that the full feature flag may introduce superfluous dependencies.
You may improve compilation times by enabling the individual features that
you need.
Client features
client: Enableclientinterfaces.client-legacy: Enable the legacyClientimplementation.client-pool: Enableclient::pool. This submodule contains interfaces for constructing connection pools.client-proxy: Enableclient::proxy.client-proxy-system: Enable platform-specific system proxy support.
Server features
server: Enableserverinterfaces.server-auto: Enable automatic HTTP version.server-graceful: Enableserver::gracefulinterfaces for gracefully shutting down a server. See the module-level documentation ofserver::gracefulfor more information.
Other features
service: Enableserviceinterfaces for compatibility with tower’sService. See the module-level documentation ofservicefor more information.http1: Enable HTTP/1 support.http2: Enable HTTP/2 support.tokio: Enablert::tokioruntime components to integrate withtokio. See the module-level documentation ofrt::tokiofor more information.tracing: Enablert::tracingruntime components to integrate withtracing. See the module-level documentation ofrt::tracingfor more information.rt-tracing-exec-force: A temporary compatibility opt-in feature to facilitate migrating telemetry from v0.1.20. If set,rt::tokio::TokioExecutor<I>will continue to propagate the currenttracing::Spanto spawned tasks. This may be removed in a future release. Note that this feature is not included in thefullfeature set, and must be explicitly enabled. See #322 and #323 for more information.