Struct Error
struct Error { ... }
Client errors
Implementations
impl Error
fn is_connect(self: &Self) -> boolReturns true if this was an error from
Connect.fn connect_info(self: &Self) -> Option<&Connected>Returns the info of the client connection on which this error occurred.
impl Debug for Error
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for Error
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Error for Error
fn source(self: &Self) -> Option<&dyn StdError + 'static>
impl Freeze for Error
impl RefUnwindSafe for Error
impl Send for Error
impl Sync for Error
impl Unpin for Error
impl UnsafeUnpin for Error
impl UnwindSafe for Error
impl<T> Any for Error
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Error
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Error
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Error
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Instrument for Error
impl<T> ToString for Error
fn to_string(self: &Self) -> String
impl<T> WithSubscriber for Error
impl<T, U> Into for Error
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Error
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Error
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>