CurrentSpanExecutor

Struct CurrentSpanExecutor 

pub struct CurrentSpanExecutor<E> { /* private fields */ }
Available on crate feature tracing only.
An executor that propagates the current tracing span to its futures.

The span is captured when execute is called, and is entered each time the future is polled or dropped. Execution is delegated to the wrapped executor, without requiring a particular runtime.

Requires the tracing feature.

Example

use hyper_util::rt::{TokioExecutor, CurrentSpanExecutor};

let executor = CurrentSpanExecutor::new(TokioExecutor::new());

Implementations

Source

impl<E> CurrentSpanExecutor<E>

pub fn new(inner: E) -> Self

Wrap an executor to propagate the current tracing span to its futures.